<?php
/**
 * @file
 * Contains \Drupal\iubenda_integration\EventSubscriber\IubendaEventSubscriber.
 */

namespace Drupal\iubenda_integration\EventSubscriber;

use Symfony\Component\HttpKernel\Event\ResponseEvent;
use iubendaParser;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event Subscriber IubendaEventSubscriber.
 */
class IubendaEventSubscriber implements EventSubscriberInterface {

  public function onKernelResponse(ResponseEvent $event) {
    $response = $event->getResponse();
    $request = $event->getRequest();

    // Do not capture redirects or modify XML HTTP Requests.
    if ($request->isXmlHttpRequest()) {
      return;
    }

    // Exclude files.
    if ($response instanceof BinaryFileResponse) {
      return;
    }

    // Parse non administrative pages only.
    $is_admin_page = \Drupal::service('router.admin_context')->isAdminRoute();
    if (!$response->isEmpty() && !$is_admin_page) {

      // Parse all page's HTML and check for cookies intent lock.
      // For more informations go to https://www.iubenda.com/en/help/posts/1976.
      if (!iubendaParser::consent_given() && !iubendaParser::bot_detected()) {
        $iubenda = new iubendaParser($response->getContent(), [
          'type' => 'page',
        ]);
        $response->setContent($iubenda->parse());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::RESPONSE => ['onKernelResponse', -128],
    ];
  }
}
